fn read_frame(stream: &mut UnixStream) -> Result<Vec<u8>>Expand description
The deadline applies to the whole frame, even if a client dribbles bytes.
fn read_frame(stream: &mut UnixStream) -> Result<Vec<u8>>The deadline applies to the whole frame, even if a client dribbles bytes.