pub struct GcReport {
pub dry_run: bool,
pub artifacts: Vec<String>,
pub leased: Vec<String>,
pub candidate_bytes: u64,
}Expand description
Garbage collection candidates and artifacts skipped because they are leased.
Fields
dry_run: boolWhether collection only inspected candidates.
artifacts: Vec<String>Artifact IDs removed, or eligible for removal during a dry run.
leased: Vec<String>Unreferenced artifact IDs skipped because their lease lock was unavailable.
candidate_bytes: u64Owned candidate file lengths; shared hard links can reduce reclaimed space.