pub struct ObjectId(pub usize);Expand description
Identifies an object within an opened checkpoint. It is not a filename or a content digest; a store can assign content identities while copying it.
Tuple Fields
0: usizeTrait Implementations
impl Copy for ObjectId
Sourceimpl<'de> Deserialize<'de> for ObjectId
impl<'de> Deserialize<'de> for ObjectId
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ObjectId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ObjectId, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ObjectId
Sourceimpl Serialize for ObjectId
impl Serialize for ObjectId
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for ObjectId