pub(super) fn fetch_into_slots(file: &File, reads: &[RecordRead])Expand description
Fill independent slots in parallel, one complete record per read.
pub(super) fn fetch_into_slots(file: &File, reads: &[RecordRead])Fill independent slots in parallel, one complete record per read.