pub(super) struct PendingRead {
pub(super) thread: Option<JoinHandle<()>>,
pub(super) records: Vec<usize>,
pub(super) tickets: Vec<(usize, ReadTicket)>,
}Expand description
A background read may be absent under the FAKE developer option, but its reserved records must still pass through residency completion.
Fields
thread: Option<JoinHandle<()>>records: Vec<usize>tickets: Vec<(usize, ReadTicket)>Auto Trait Implementations
impl !RefUnwindSafe for PendingRead
impl !UnwindSafe for PendingRead
impl Freeze for PendingRead
impl Send for PendingRead
impl Sync for PendingRead
impl Unpin for PendingRead
impl UnsafeUnpin for PendingRead