pub struct ExpertLayout {Show 17 fields
pub layers: usize,
pub experts: usize,
pub inter: usize,
pub hidden: usize,
pub group: usize,
pub record_bytes: u64,
pub record_stride: u64,
pub layer_prefixes: Vec<String>,
pub gate_w: u64,
pub up_w: u64,
pub down_w: u64,
pub gate_s: u64,
pub gate_b: u64,
pub up_s: u64,
pub up_b: u64,
pub down_s: u64,
pub down_b: u64,
}Expand description
Expert record layout inside experts.bin. One record per (layer, expert):
three packed 4-bit weight matrices followed by their scales and biases,
padded to a page multiple so each record can be its own Metal buffer.
Fields
layers: usizeexperts: usizeinter: usizegroup: usizerecord_bytes: u64record_stride: u64layer_prefixes: Vec<String>Tensor prefixes in record order (main layers, then MTP layers).
gate_w: u64up_w: u64down_w: u64gate_s: u64gate_b: u64up_s: u64up_b: u64down_s: u64down_b: u64Implementations
Sourceimpl ExpertLayout
impl ExpertLayout
pub(crate) fn validate_dimensions(&self) -> Result<()>