pub(crate) struct ParsedToolCallOutput {
pub is_tool_call_response: bool,
pub content: String,
pub tool_calls: Vec<GeneratedToolCall>,
pub diagnostics: ToolCallParseDiagnostics,
}Fields
is_tool_call_response: boolcontent: StringPre-marker content, or the whole input on fallback. The streaming decoder holds the region from the marker on, so it only reconstructs held bytes when a marker is present.
tool_calls: Vec<GeneratedToolCall>diagnostics: ToolCallParseDiagnosticsAuto Trait Implementations
impl Freeze for ParsedToolCallOutput
impl RefUnwindSafe for ParsedToolCallOutput
impl Send for ParsedToolCallOutput
impl Sync for ParsedToolCallOutput
impl Unpin for ParsedToolCallOutput
impl UnsafeUnpin for ParsedToolCallOutput
impl UnwindSafe for ParsedToolCallOutput