struct Active<'a> {Show 13 fields
prepared: PreparedRequest,
phase: Phase,
checkpoint: Option<PrefixState>,
reservation: usize,
ticket: Arc<Ticket>,
session: Option<Turn>,
output: Output,
text_decoder: Box<dyn FnMut(u32) -> Result<Option<String>> + 'a>,
text: GeneratedText,
usage: UsageStats,
config_generation: u64,
response_bytes: usize,
last_chunk: Option<(usize, f64)>,
}Fields
prepared: PreparedRequestphase: Phasecheckpoint: Option<PrefixState>reservation: usizeticket: Arc<Ticket>session: Option<Turn>output: Outputtext_decoder: Box<dyn FnMut(u32) -> Result<Option<String>> + 'a>text: GeneratedTextusage: UsageStatsconfig_generation: u64response_bytes: usizelast_chunk: Option<(usize, f64)>Tokens and elapsed seconds from the last step, if eligible for pacing.
Implementations
Sourceimpl Active<'_>
impl Active<'_>
fn stats(&self) -> ActiveRequest
fn phase_name(&self) -> &'static str
fn generated(&self) -> &[u32]
Sourcefn report(&self, gpu: &Gpu<'_>)
fn report(&self, gpu: &Gpu<'_>)
Per-request throughput and context/KV-cache fullness, reported to the server console when the request completes.
fn step( &mut self, gpu: &mut Gpu<'_>, cache: &mut PrefixCache, tok: &ChatTokenizer, state: &State, quantum: usize, ) -> Result<bool>
fn finish(self, tok: &ChatTokenizer) -> Result<()>
fn finish_response(&mut self, tok: &ChatTokenizer) -> Result<()>